Documentation
¶
Overview ¶
Package workspace validates and contains access to a configured Go workspace.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Workspace ¶
type Workspace struct {
// contains filtered or unexported fields
}
Workspace is a validated, symlink-resolved Go workspace root.
func (*Workspace) Relative ¶
Relative returns an existing contained path relative to the workspace root.
func (*Workspace) RequiredGo ¶
RequiredGo returns the highest Go version required by the active workspace.
func (*Workspace) Resolve ¶
Resolve resolves an existing path and rejects anything outside the workspace.
Click to show internal directories.
Click to hide internal directories.